@@ -29,7 +29,7 @@
 #include <QToolTip>
 #include <QGraphicsSceneMouseEvent>
 
-AbstractClipItem::AbstractClipItem(const ItemInfo info, const QRectF& rect, double fps) :
+AbstractClipItem::AbstractClipItem(const ItemInfo &info, const QRectF& rect, double fps) :
         QObject(),
         QGraphicsRectItem(rect),
         m_info(info),
@@ -203,19 +203,22 @@ void AbstractClipItem::resizeEnd(int posx)
     setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
     if (durationDiff > GenTime()) {
         QList <QGraphicsItem *> collisionList = collidingItems(Qt::IntersectsItemBoundingRect);
+        bool fixItem = false;
         for (int i = 0; i < collisionList.size(); ++i) {
             if (!collisionList.at(i)->isEnabled()) continue;
             QGraphicsItem *item = collisionList.at(i);
             if (item->type() == type() && item->pos().x() > pos().x()) {
-                kDebug() << "/////////  COLLISION DETECTED!!!!!!!!!";
-                kDebug() << "/////////  CURRENT: " << startPos().frames(25) << "x" << endPos().frames(25) << ", RECT: " << rect() << "-" << pos();
-                kDebug() << "/////////  COLLISION: " << ((AbstractClipItem *)item)->startPos().frames(25) << "x" << ((AbstractClipItem *)item)->endPos().frames(25) << ", RECT: " << ((AbstractClipItem *)item)->rect() << "-" << item->pos();
+                //kDebug() << "/////////  COLLISION DETECTED!!!!!!!!!";
+                //kDebug() << "/////////  CURRENT: " << startPos().frames(25) << "x" << endPos().frames(25) << ", RECT: " << rect() << "-" << pos();
+                //kDebug() << "/////////  COLLISION: " << ((AbstractClipItem *)item)->startPos().frames(25) << "x" << ((AbstractClipItem *)item)->endPos().frames(25) << ", RECT: " << ((AbstractClipItem *)item)->rect() << "-" << item->pos();
                 GenTime diff = ((AbstractClipItem *)item)->startPos() - startPos();
-                m_info.cropDuration = diff;
-                setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
-                break;
+                if (fixItem == false || diff < m_info.cropDuration) {
+                    fixItem = true;
+                    m_info.cropDuration = diff;
+                }
             }
         }
+        if (fixItem) setRect(0, 0, cropDuration().frames(m_fps) - 0.02, rect().height());
     }
 }
 
@@ -246,7 +249,7 @@ GenTime AbstractClipItem::maxDuration() const
     return m_maxDuration;
 }
 
-void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
+void AbstractClipItem::drawKeyFrames(QPainter *painter, bool limitedKeyFrames)
 {
     if (m_keyframes.count() < 1)
         return;
@@ -262,9 +265,15 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
     if (active) {
         x1 = br.x();
         x2 = br.right();
+        if (limitedKeyFrames) {
+            QMap<int, int>::const_iterator end = m_keyframes.constEnd();
+            end--;
+            x2 = x1 + maxw * (end.key() - start);
+            x1 += maxw * (m_keyframes.constBegin().key() - start);
+        }
         y1 = br.bottom() - (m_keyframeDefault - m_keyframeOffset) * maxh;
         QLineF l(x1, y1, x2, y1);
-        QLineF l2 = painter->matrix().map(l);
+        QLineF l2 = painter->worldTransform().map(l);
         painter->setPen(QColor(168, 168, 168, 180));
         painter->drawLine(l2);
         painter->setPen(QColor(108, 108, 108, 180));
@@ -280,10 +289,12 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
     x1 = br.x() + maxw * (i.key() - start);
     y1 = br.bottom() - (i.value() - m_keyframeOffset) * maxh;
 
+
+
     // make sure line begins with clip beginning
-    if (i.key() != start) {
+    if (!limitedKeyFrames && i.key() != start) {
         QLineF l(br.x(), y1, x1, y1);
-        l2 = painter->matrix().map(l);
+        l2 = painter->worldTransform().map(l);
         painter->drawLine(l2);
     }
     while (i != m_keyframes.constEnd()) {
@@ -303,7 +314,7 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
             y2 = br.bottom() - (i.value() - m_keyframeOffset) * maxh;
         }
         QLineF l(x1, y1, x2, y2);
-        l2 = painter->matrix().map(l);
+        l2 = painter->worldTransform().map(l);
         painter->drawLine(l2);
         if (active) {
             const QRectF frame(l2.x1() - 3, l2.y1() - 3, 6, 6);
@@ -314,9 +325,9 @@ void AbstractClipItem::drawKeyFrames(QPainter *painter, QRectF /*exposedRect*/)
     }
 
     // make sure line ends at clip end
-    if (x1 != br.right()) {
+    if (!limitedKeyFrames && x1 != br.right()) {
         QLineF l(x1, y1, br.right(), y1);
-        painter->drawLine(painter->matrix().map(l));
+        painter->drawLine(painter->worldTransform().map(l));
     }
 
     if (active && m_keyframes.count() > 1) {
@@ -384,7 +395,7 @@ double AbstractClipItem::selectedKeyFrameValue() const
     return m_keyframes.value(m_selectedKeyframe);
 }
 
-void AbstractClipItem::updateKeyFramePos(const GenTime pos, const double value)
+void AbstractClipItem::updateKeyFramePos(const GenTime &pos, const double value)
 {
     if (!m_keyframes.contains(m_editedKeyframe))
         return;
@@ -426,7 +437,7 @@ int AbstractClipItem::keyFrameNumber() const
     return m_keyframes.count();
 }
 
-int AbstractClipItem::addKeyFrame(const GenTime pos, const double value)
+int AbstractClipItem::addKeyFrame(const GenTime &pos, const double value)
 {
     QRectF br = sceneBoundingRect();
     double maxh = 100.0 / br.height() / m_keyframeFactor;
@@ -487,3 +498,14 @@ void AbstractClipItem::mousePressEvent(QGraphicsSceneMouseEvent * event)
     }
 }
 
+int AbstractClipItem::itemHeight()
+{
+    return 0;
+}
+
+int AbstractClipItem::itemOffset()
+{
+    return 0;
+}
+
+
