@@ -57,14 +57,14 @@ int AbstractGroupItem::track() const
 
 void AbstractGroupItem::setItemLocked(bool locked)
 {
-    if (locked) {
+    if (locked)
         setSelected(false);
-        setFlag(QGraphicsItem::ItemIsMovable, false);
-        setFlag(QGraphicsItem::ItemIsSelectable, false);
-    } else {
-        setFlag(QGraphicsItem::ItemIsMovable, true);
-        setFlag(QGraphicsItem::ItemIsSelectable, true);
-    }
+
+    setFlag(QGraphicsItem::ItemIsMovable, !locked);
+    setFlag(QGraphicsItem::ItemIsSelectable, !locked);
+
+    foreach (QGraphicsItem *child, childItems())
+        ((AbstractClipItem *)child)->setItemLocked(locked);
 }
 
 bool AbstractGroupItem::isItemLocked() const
@@ -355,7 +355,7 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
 //virtual
 void AbstractGroupItem::dropEvent(QGraphicsSceneDragDropEvent * event)
 {
-    QString effects = QString(event->mimeData()->data("kdenlive/effectslist"));
+    QString effects = QString::fromUtf8(event->mimeData()->data("kdenlive/effectslist"));
     QDomDocument doc;
     doc.setContent(effects, true);
     QDomElement e = doc.documentElement();
@@ -371,7 +371,7 @@ void AbstractGroupItem::dragEnterEvent(QGraphicsSceneDragDropEvent *event)
 
 void AbstractGroupItem::dragLeaveEvent(QGraphicsSceneDragDropEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
 }
 
 // virtual
