@@ -12,7 +12,7 @@ class BMInterface
 public:
     BMInterface();
     ~BMInterface();
-    static bool getBlackMagicDeviceList(KComboBox *devicelist, KComboBox *modelist);
+    static bool getBlackMagicDeviceList(KComboBox *devicelist);
     static bool getBlackMagicOutputDeviceList(KComboBox *devicelist);
     static bool isSupportedProfile(int card, QMap< QString, QString > properties);
     static QStringList supportedModes(int card);
