@@ -27,7 +27,6 @@
 #include <QTreeWidgetItem>
 #include <KLocale>
 
-const int FRAME_SIZE = 90;
 const int MAXCLIPDURATION = 15000;
 
 enum OPERATIONTYPE { NONE = 0, MOVE = 1, RESIZESTART = 2, RESIZEEND = 3, FADEIN = 4, FADEOUT = 5, TRANSITIONSTART = 6, TRANSITIONEND = 7, MOVEGUIDE = 8, KEYFRAME = 9, SEEK = 10, SPACER = 11, RUBBERSELECTION = 12};
@@ -58,7 +57,7 @@ enum MessageType {
 
 enum TRACKTYPE { AUDIOTRACK = 0, VIDEOTRACK = 1 };
 
-enum PROXYSTATUS { NOPROXY = 0, PROXYWAITING = 1, CREATINGPROXY = 2, PROXYDONE = 3, PROXYCRASHED = 4};
+enum PROXYSTATUS { NOPROXY = 0, PROXYWAITING = -1, CREATINGPROXY = -2, PROXYDONE = -3, PROXYCRASHED = -4};
 
 struct TrackInfo {
     TRACKTYPE type;
@@ -70,6 +69,9 @@ struct TrackInfo {
     int duration;
 };
 
+typedef QMap<QString, QString> stringMap;
+typedef QMap <int, QMap <int, QByteArray> > audioByteArray;
+
 struct ItemInfo {
     /** startPos is the position where the clip starts on the track */
     GenTime startPos;
@@ -101,14 +103,14 @@ struct MltVideoProfile {
 class EffectParameter
 {
 public:
-    EffectParameter(const QString name, const QString value): m_name(name), m_value(value) {}
+    EffectParameter(const QString &name, const QString &value): m_name(name), m_value(value) {}
     QString name()   const          {
         return m_name;
     }
     QString value() const          {
         return m_value;
     }
-    void setValue(const QString value) {
+    void setValue(const QString &value) {
         m_value = value;
     }
 
@@ -124,12 +126,12 @@ class EffectsParameterList: public QList < EffectParameter >
 {
 public:
     EffectsParameterList(): QList < EffectParameter >() {}
-    bool hasParam(const QString name) const {
+    bool hasParam(const QString &name) const {
         for (int i = 0; i < size(); i++)
             if (at(i).name() == name) return true;
         return false;
     }
-    QString paramValue(const QString name, QString defaultValue = QString()) const {
+    QString paramValue(const QString &name, QString defaultValue = QString()) const {
         for (int i = 0; i < size(); i++) {
             if (at(i).name() == name) return at(i).value();
         }
@@ -139,7 +141,7 @@ public:
         if (name.isEmpty()) return;
         append(EffectParameter(name, value));
     }
-    void removeParam(const QString name) {
+    void removeParam(const QString &name) {
         for (int i = 0; i < size(); i++)
             if (at(i).name() == name) {
                 removeAt(i);
@@ -152,7 +154,7 @@ class CommentedTime
 {
 public:
     CommentedTime(): t(GenTime(0)) {}
-    CommentedTime(const GenTime time, QString comment)
+    CommentedTime(const GenTime &time, QString comment)
         : t(time), c(comment) { }
 
     QString comment()   const          {
