@@ -24,6 +24,9 @@
 #include <QDomDocument>
 #include <QColor>
 
+class QScriptValue;
+
+
 class DocumentValidator
 {
 
@@ -37,7 +40,13 @@ private:
     QDomDocument m_doc;
     bool m_modified;
     bool upgrade(double version, const double currentVersion);
+    QStringList getInfoFromEffectName(const QString oldName);
     QString colorToString(const QColor& c);
+    /** @brief Updates effects that were created using a different version of the underlaying filter than the one installed. */
+    void updateEffects();
+    /** @brief Updates the parameters according to the updateRules.
+     * @see the related in README in effects/update */
+    bool updateEffectParameters(QDomNodeList parameters, const QScriptValue *updateRules, const double serviceVersion, const double effectVersion);
 };
 
 #endif
