@@ -48,6 +48,11 @@ private:
     DvdWizardVob *m_pageVob;
     DvdWizardMenu *m_pageMenu;
     Ui::DvdWizardStatus_UI m_status;
+
+#if KDE_IS_VERSION(4,7,0)
+    KMessageWidget *m_isoMessage;
+#endif
+
     DvdWizardChapters *m_pageChapters;
     KTemporaryFile m_authorFile;
     KTemporaryFile m_menuFile;
