@@ -120,16 +120,18 @@ void DvdWizardVob::slotAddVobFile(KUrl url, const QString &chapters)
 
     if (producer->is_blank() == false) {
         int width = 45.0 * profile.dar();
+        int swidth = 45.0 * profile.width() / profile.height();
         if (width % 2 == 1) width++;
-        item->setIcon(0, QPixmap::fromImage(KThumb::getFrame(producer, 0, width, 45)));
+        item->setIcon(0, QPixmap::fromImage(KThumb::getFrame(producer, 0, swidth, width, 45)));
         int playTime = producer->get_playtime();
         item->setText(1, Timecode::getStringTimecode(playTime, profile.fps()));
         item->setData(1, Qt::UserRole, playTime);
     }
     delete producer;
 
-    if (chapters.isEmpty() == false)
+    if (chapters.isEmpty() == false) {
         item->setData(1, Qt::UserRole + 1, chapters);
+    }
     else if (QFile::exists(url.path() + ".dvdchapter")) {
         // insert chapters as children
         QFile file(url.path() + ".dvdchapter");
@@ -245,7 +247,9 @@ QStringList DvdWizardVob::chapters() const
     int max = m_view.vobs_list->topLevelItemCount();
     for (int i = 0; i < max; i++) {
         QTreeWidgetItem *item = m_view.vobs_list->topLevelItem(i);
-        if (item) result.append(item->data(1, Qt::UserRole + 1).toString());
+        if (item) {
+            result.append(item->data(1, Qt::UserRole + 1).toString());
+        }
     }
     return result;
 }
@@ -255,7 +259,7 @@ void DvdWizardVob::updateChapters(QMap <QString, QString> chaptersdata)
     int max = m_view.vobs_list->topLevelItemCount();
     for (int i = 0; i < max; i++) {
         QTreeWidgetItem *item = m_view.vobs_list->topLevelItem(i);
-        item->setData(1, Qt::UserRole + 1, chaptersdata.value(item->text(0)));
+        if (chaptersdata.contains(item->text(0))) item->setData(1, Qt::UserRole + 1, chaptersdata.value(item->text(0)));
     }
 }
 
@@ -276,7 +280,7 @@ QString DvdWizardVob::introMovie() const
     return m_view.intro_vob->url().path();
 }
 
-void DvdWizardVob::setIntroMovie(const QString path)
+void DvdWizardVob::setIntroMovie(const QString& path)
 {
     m_view.intro_vob->setUrl(KUrl(path));
     m_view.use_intro->setChecked(path.isEmpty() == false);
@@ -338,7 +342,7 @@ bool DvdWizardVob::isWide() const
     return (m_view.dvd_profile->currentIndex() == 1 || m_view.dvd_profile->currentIndex() == 3);
 }
 
-void DvdWizardVob::setProfile(const QString profile)
+void DvdWizardVob::setProfile(const QString& profile)
 {
     if (profile == "dv_pal") m_view.dvd_profile->setCurrentIndex(0);
     else if (profile == "dv_pal_wide") m_view.dvd_profile->setCurrentIndex(1);
