@@ -31,7 +31,7 @@ class CustomTrackView;
 class EditEffectCommand : public QUndoCommand
 {
 public:
-    EditEffectCommand(CustomTrackView *view, const int track, GenTime pos, QDomElement oldeffect, QDomElement effect, int stackPos, bool doIt);
+    EditEffectCommand(CustomTrackView *view, const int track, GenTime pos, QDomElement oldeffect, QDomElement effect, int stackPos, bool doIt, QUndoCommand *parent = 0);
 
     virtual int id() const;
     virtual bool mergeWith(const QUndoCommand * command);
@@ -41,8 +41,8 @@ public:
 private:
     CustomTrackView *m_view;
     const int m_track;
-    QDomElement m_effect;
     QDomElement m_oldeffect;
+    QDomElement m_effect;
     const GenTime m_pos;
     int m_stackPos;
     bool m_doIt;
