@@ -58,7 +58,8 @@ public:
     QStringList effectNames();
     QString getInfo(const QString & tag, const QString & id) const;
     QString getInfoFromIndex(const int ix) const;
-    void clone(const EffectsList original);
+    QString getEffectInfo(const QDomElement effect) const;
+    void clone(const EffectsList &original);
     void append(QDomElement e);
     bool isEmpty() const;
     int count() const;
@@ -74,10 +75,14 @@ public:
     static QString parameter(QDomElement effect, const QString &name);
     /** @brief Change the value of a 'property' element from the effect node. */
     static void setProperty(QDomElement effect, const QString &name, const QString &value);
+    /** @brief Rename a 'property' element from the effect node. */
+    static void renameProperty(QDomElement effect, const QString &oldName, const QString &newName);
     /** @brief Get the value of a 'property' element from the effect node. */
     static QString property(QDomElement effect, const QString &name);
     /** @brief Delete a 'property' element from the effect node. */
     static void removeProperty(QDomElement effect, const QString &name);
+    /** @brief Remove all 'meta.*' properties from a producer, used when replacing proxy producers in xml for rendering. */
+    static void removeMetaProperties(QDomElement producer);
     void clearList();
 
 private:
