@@ -49,11 +49,12 @@ EffectStackView::EffectStackView(Monitor *monitor, QWidget *parent) :
     m_ui.setupUi(this);
     QVBoxLayout *vbox1 = new QVBoxLayout(m_ui.frame);
     m_effectedit = new EffectStackEdit(monitor, m_ui.frame);
+    m_ui.frame->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     vbox1->setContentsMargins(2, 0, 2, 0);
     vbox1->setSpacing(0);
     vbox1->addWidget(m_effectedit);
-    m_ui.splitter->setStretchFactor(0, 0);
-    m_ui.splitter->setStretchFactor(1, 200);
+    m_ui.splitter->setStretchFactor(0, 1);
+    m_ui.splitter->setStretchFactor(1, 20);
 
     //m_ui.region_url->fileDialog()->setFilter(ProjectList::getExtensions());
     //m_ui.effectlist->horizontalHeader()->setVisible(false);
@@ -90,7 +91,7 @@ EffectStackView::EffectStackView(Monitor *monitor, QWidget *parent) :
     connect(m_ui.buttonReset, SIGNAL(clicked()), this, SLOT(slotResetEffect()));
     connect(m_ui.checkAll, SIGNAL(stateChanged(int)), this, SLOT(slotCheckAll(int)));
     connect(m_ui.buttonShowComments, SIGNAL(clicked()), this, SLOT(slotShowComments()));
-    connect(m_effectedit, SIGNAL(parameterChanged(const QDomElement, const QDomElement)), this , SLOT(slotUpdateEffectParams(const QDomElement, const QDomElement)));
+    connect(m_effectedit, SIGNAL(parameterChanged(const QDomElement &, const QDomElement &)), this , SLOT(slotUpdateEffectParams(const QDomElement &, const QDomElement &)));
     connect(m_effectedit, SIGNAL(seekTimeline(int)), this , SLOT(slotSeekTimeline(int)));
     connect(m_effectedit, SIGNAL(displayMessage(const QString&, int)), this, SIGNAL(displayMessage(const QString&, int)));
     connect(m_effectedit, SIGNAL(checkMonitorPosition(int)), this, SLOT(slotCheckMonitorPosition(int)));
@@ -99,9 +100,6 @@ EffectStackView::EffectStackView(Monitor *monitor, QWidget *parent) :
     m_effectLists["audio"] = &MainWindow::audioEffects;
     m_effectLists["video"] = &MainWindow::videoEffects;
     m_effectLists["custom"] = &MainWindow::customEffects;
-    m_ui.splitter->setStretchFactor(1, 10);
-    m_ui.splitter->setStretchFactor(0, 1);
-
     setEnabled(false);
 }
 
@@ -161,7 +159,7 @@ void EffectStackView::slotSaveEffect()
     emit reloadEffects();
 }
 
-void EffectStackView::slotUpdateEffectParams(const QDomElement old, const QDomElement e)
+void EffectStackView::slotUpdateEffectParams(const QDomElement &old, const QDomElement &e)
 {
     if (m_trackMode)
         emit updateEffect(NULL, m_trackindex, old, e, m_ui.effectlist->currentRow());
@@ -199,7 +197,8 @@ void EffectStackView::slotClipItemSelected(ClipItem* c, int ix)
     if (m_clipref == NULL) {
         m_ui.effectlist->blockSignals(true);
         m_ui.effectlist->clear();
-        m_effectedit->transferParamDesc(QDomElement(), 0, 0, 0);
+        ItemInfo info;
+        m_effectedit->transferParamDesc(QDomElement(), info);
         //m_ui.region_url->clear();
         m_ui.effectlist->blockSignals(false);
         m_ui.checkAll->setToolTip(QString());
@@ -267,17 +266,17 @@ void EffectStackView::setupListView(int ix)
         doc.appendChild(doc.importNode(d, true));
         kDebug() << "IMPORTED STK: " << doc.toString();*/
 
-        QDomNode namenode = d.elementsByTagName("name").item(0);
+        QDomElement namenode = d.firstChildElement("name");
         if (!namenode.isNull()) {
             // Issue 238: Add icons for effect type in effectstack.
             // Logic more or less copied from initeffects.cpp
             QString type = d.attribute("type", QString());
             if ("audio" == type) {
-                item = new QListWidgetItem(audioIcon, i18n(namenode.toElement().text().toUtf8().data()), m_ui.effectlist);
+                item = new QListWidgetItem(audioIcon, i18n(namenode.text().toUtf8().data()), m_ui.effectlist);
             } else if ("custom" == type) {
-                item = new QListWidgetItem(customIcon, i18n(namenode.toElement().text().toUtf8().data()), m_ui.effectlist);
+                item = new QListWidgetItem(customIcon, i18n(namenode.text().toUtf8().data()), m_ui.effectlist);
             } else {
-                item = new QListWidgetItem(videoIcon, i18n(namenode.toElement().text().toUtf8().data()), m_ui.effectlist);
+                item = new QListWidgetItem(videoIcon, i18n(namenode.text().toUtf8().data()), m_ui.effectlist);
             }
             item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
             if (d.attribute("disable") == "1")
@@ -302,7 +301,8 @@ void EffectStackView::setupListView(int ix)
     }
     m_ui.effectlist->blockSignals(false);
     if (m_ui.effectlist->count() == 0) {
-        m_effectedit->transferParamDesc(QDomElement(), 0, 0, 0);
+        ItemInfo info;
+        m_effectedit->transferParamDesc(QDomElement(), info);
         //m_ui.region_url->clear();
     } else slotItemSelectionChanged(false);
     slotUpdateCheckAllButton();
@@ -319,11 +319,16 @@ void EffectStackView::slotItemSelectionChanged(bool update)
         eff = m_currentEffectList.at(activeRow);
         if (m_trackMode) {
             // showing track effects
-            m_effectedit->transferParamDesc(eff, 0, 0, m_trackInfo.duration);
-        } else m_effectedit->transferParamDesc(eff,
-                                                   0,
-                                                   m_clipref->cropStart().frames(KdenliveSettings::project_fps()),
-                                                   (m_clipref->cropStart() + m_clipref->cropDuration()).frames(KdenliveSettings::project_fps()) - 1); //minx max frame
+            ItemInfo info;
+            info.track = m_trackInfo.type;
+            info.cropDuration = GenTime(m_trackInfo.duration, KdenliveSettings::project_fps());
+            info.cropStart = GenTime(0);
+            info.startPos = GenTime(-1);
+            info.track = 0;
+            m_effectedit->transferParamDesc(eff, info);
+        } else {
+            m_effectedit->transferParamDesc(eff, m_clipref->info());
+        }
         //m_ui.region_url->setUrl(KUrl(eff.attribute("region")));
         m_ui.labelComment->setText(i18n(eff.firstChildElement("description").firstChildElement("full").text().toUtf8().data()));
     }
@@ -386,11 +391,17 @@ void EffectStackView::slotResetEffect()
         if (m_trackMode) {
             EffectsList::setParameter(dom, "in", QString::number(0));
             EffectsList::setParameter(dom, "out", QString::number(m_trackInfo.duration));
-            m_effectedit->transferParamDesc(dom, 0, 0, m_trackInfo.duration);//minx max frame
+            ItemInfo info;
+            info.track = m_trackInfo.type;
+            info.cropDuration = GenTime(m_trackInfo.duration, KdenliveSettings::project_fps());
+            info.cropStart = GenTime(0);
+            info.startPos = GenTime(-1);
+            info.track = 0;
+            m_effectedit->transferParamDesc(dom, info);
             emit updateEffect(NULL, m_trackindex, old, dom, activeRow);
         } else {
             m_clipref->initEffect(dom);
-            m_effectedit->transferParamDesc(dom, 0, m_clipref->cropStart().frames(KdenliveSettings::project_fps()), (m_clipref->cropStart() + m_clipref->cropDuration()).frames(KdenliveSettings::project_fps()));//minx max frame
+            m_effectedit->transferParamDesc(dom, m_clipref->info());
             //m_ui.region_url->setUrl(KUrl(dom.attribute("region")));
             emit updateEffect(m_clipref, -1, old, dom, activeRow);
         }
@@ -417,8 +428,10 @@ void EffectStackView::clear()
     m_ui.buttonUp->setEnabled(false);
     m_ui.buttonDown->setEnabled(false);
     m_ui.checkAll->setEnabled(false);
-    m_effectedit->transferParamDesc(QDomElement(), 0, 0, 0);
+    ItemInfo info;
+    m_effectedit->transferParamDesc(QDomElement(), info);
     //m_ui.region_url->clear();
+    m_clipref = NULL;
     m_ui.buttonShowComments->setEnabled(false);
     m_ui.labelComment->setText(QString());
     m_ui.effectlist->blockSignals(false);
