@@ -60,12 +60,18 @@ private slots:
     void slotDeleteUnused();
     /** @brief Export project data to text file. */
     void slotExportToText();
+    /** @brief Update the displayed proxy parameters when user changes selection. */
+    void slotUpdateProxyParams();
 
 private:
     QPushButton *m_buttonOk;
     bool m_savedProject;
     ProjectList *m_projectList;
     QStringList m_lumas;
+
+signals:
+    /** @brief User deleted proxies, so disable them in project. */
+    void disableProxies();
 };
 
 
