@@ -20,12 +20,15 @@
 
 #include "recmonitor.h"
 #include "gentime.h"
+#include "mltdevicecapture.h"
 #include "kdenlivesettings.h"
 #include "managecapturesdialog.h"
+#include "monitormanager.h"
+#include "monitor.h"
+#include "profilesdialog.h"
 
 #include <KDebug>
 #include <KLocale>
-#include <QPainter>
 #include <KStandardDirs>
 #include <KComboBox>
 #include <KIO/NetAccess>
@@ -44,15 +47,15 @@
 #include <QDir>
 
 
-RecMonitor::RecMonitor(QString name, QWidget *parent) :
-    QWidget(parent),
+RecMonitor::RecMonitor(QString name, MonitorManager *manager, QWidget *parent) :
+    AbstractMonitor(parent),
     m_name(name),
-    m_isActive(false),
     m_isCapturing(false),
     m_didCapture(false),
     m_isPlaying(false),
-    m_bmCapture(NULL),
-    m_blackmagicCapturing(false)
+    m_manager(manager),
+    m_captureDevice(NULL),
+    m_analyse(false)
 {
     setupUi(this);
 
@@ -60,6 +63,16 @@ RecMonitor::RecMonitor(QString name, QWidget *parent) :
     device_selector->setCurrentIndex(KdenliveSettings::defaultcapture());
     connect(device_selector, SIGNAL(currentIndexChanged(int)), this, SLOT(slotVideoDeviceChanged(int)));
 
+    // Video widget holder
+    QVBoxLayout *l = new QVBoxLayout;
+    l->setContentsMargins(0, 0, 0, 0);
+    l->setSpacing(0);
+    m_videoBox = new VideoPreviewContainer();
+    m_videoBox->setContentsMargins(0, 0, 0, 0);
+    m_videoBox->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+    l->addWidget(m_videoBox);
+    video_frame->setLayout(l);
+
     QToolBar *toolbar = new QToolBar(this);
     QHBoxLayout *layout = new QHBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
@@ -73,7 +86,7 @@ RecMonitor::RecMonitor(QString name, QWidget *parent) :
     connect(m_rewAction, SIGNAL(triggered()), this, SLOT(slotRewind()));
 
     m_playAction = toolbar->addAction(m_playIcon, i18n("Play"));
-    connect(m_playAction, SIGNAL(triggered()), this, SLOT(slotStartCapture()));
+    connect(m_playAction, SIGNAL(triggered()), this, SLOT(slotStartPreview()));
 
     m_stopAction = toolbar->addAction(KIcon("media-playback-stop"), i18n("Stop"));
     connect(m_stopAction, SIGNAL(triggered()), this, SLOT(slotStopCapture()));
@@ -112,37 +125,42 @@ RecMonitor::RecMonitor(QString name, QWidget *parent) :
 #endif
 
     control_frame_firewire->setLayout(layout);
-
-    slotVideoDeviceChanged(device_selector->currentIndex());
     m_displayProcess = new QProcess;
     m_captureProcess = new QProcess;
 
     connect(m_captureProcess, SIGNAL(stateChanged(QProcess::ProcessState)), this, SLOT(slotProcessStatus(QProcess::ProcessState)));
     connect(m_captureProcess, SIGNAL(readyReadStandardError()), this, SLOT(slotReadDvgrabInfo()));
 
+    
+    QString videoDriver = KdenliveSettings::videodrivername();
+#if QT_VERSION >= 0x040600
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    env.insert("SDL_WINDOWID", QString::number(video_frame->winId()));
+    if (!videoDriver.isEmpty()) {
+        if (videoDriver == "x11_noaccel") {
+            env.insert("SDL_VIDEO_YUV_HWACCEL", "0");
+            env.insert("SDL_VIDEODRIVER", "x11");
+        } else env.insert("SDL_VIDEODRIVER", videoDriver);
+    }
+    m_displayProcess->setProcessEnvironment(env);
+#else
     QStringList env = QProcess::systemEnvironment();
     env << "SDL_WINDOWID=" + QString::number(video_frame->winId());
-
-    QString videoDriver = KdenliveSettings::videodrivername();
     if (!videoDriver.isEmpty()) {
         if (videoDriver == "x11_noaccel") {
             env << "SDL_VIDEO_YUV_HWACCEL=0";
             env << "SDL_VIDEODRIVER=x11";
         } else env << "SDL_VIDEODRIVER=" + videoDriver;
     }
+    m_displayProcess->setEnvironment(env);
+#endif
     setenv("SDL_VIDEO_ALLOW_SCREENSAVER", "1", 1);
 
-    m_displayProcess->setEnvironment(env);
-
-    if (KdenliveSettings::video4capture().isEmpty()) {
-        QString captureCommand;
-        if (!KdenliveSettings::video4adevice().isEmpty()) captureCommand = "-f " + KdenliveSettings::video4aformat() + " -i " + KdenliveSettings::video4adevice() + " -acodec " + KdenliveSettings::video4acodec();
-
-        captureCommand +=  " -f " + KdenliveSettings::video4vformat() + " -s " + KdenliveSettings::video4size() + " -r " + QString::number(KdenliveSettings::video4rate()) + " -i " + KdenliveSettings::video4vdevice() + " -vcodec " + KdenliveSettings::video4vcodec();;
-        KdenliveSettings::setVideo4capture(captureCommand);
-    }
-
     kDebug() << "/////// BUILDING MONITOR, ID: " << video_frame->winId();
+    slotVideoDeviceChanged(device_selector->currentIndex());
+    recording_preview->setToolTip(i18n("Capture preview settings"));
+    recording_preview->setCurrentIndex(KdenliveSettings::recording_preview());
+    connect(recording_preview, SIGNAL(currentIndexChanged(int)), this, SLOT(slotChangeRecordingPreview(int)));
 }
 
 RecMonitor::~RecMonitor()
@@ -152,19 +170,29 @@ RecMonitor::~RecMonitor()
 #endif
     delete m_captureProcess;
     delete m_displayProcess;
+    if (m_captureDevice) delete m_captureDevice;
 }
 
-QString RecMonitor::name() const
+const QString RecMonitor::name() const
 {
     return m_name;
 }
 
+void RecMonitor::stop()
+{
+    slotStopCapture();
+}
+
+void RecMonitor::start()
+{
+}
+
 void RecMonitor::slotConfigure()
 {
     emit showConfigDialog(4, device_selector->currentIndex());
 }
 
-void RecMonitor::slotUpdateCaptureFolder(const QString currentProjectFolder)
+void RecMonitor::slotUpdateCaptureFolder(const QString &currentProjectFolder)
 {
     if (KdenliveSettings::capturetoprojectfolder()) m_capturePath = currentProjectFolder;
     else m_capturePath = KdenliveSettings::capturefolder();
@@ -185,18 +213,28 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
 {
     QString capturefile;
     QString capturename;
-    video_capture->setHidden(true);
-    video_frame->setHidden(false);
-    m_fwdAction->setVisible(ix != BLACKMAGIC);
-    m_discAction->setVisible(ix != BLACKMAGIC);
-    m_rewAction->setVisible(ix != BLACKMAGIC);
+    recording_preview->setHidden(ix != VIDEO4LINUX && ix != BLACKMAGIC);
+    m_fwdAction->setVisible(ix == FIREWIRE);
+    m_discAction->setVisible(ix == FIREWIRE);
+    m_rewAction->setVisible(ix == FIREWIRE);
+    m_recAction->setEnabled(ix != FIREWIRE);
     m_logger.setVisible(ix == BLACKMAGIC);
+    if (m_captureDevice) {
+        // MLT capture still running, abort
+        m_captureDevice->stop();
+        delete m_captureDevice;
+        m_captureDevice = NULL;
+        m_manager->clearScopeSource();
+    }
+
+    // The m_videoBox container has to be shown once before the MLT consumer is build, or preview will fail
+    m_videoBox->setHidden(ix != VIDEO4LINUX && ix != BLACKMAGIC);
+    m_videoBox->setHidden(true);
     switch (ix) {
     case SCREENGRAB:
         m_discAction->setEnabled(false);
         m_rewAction->setEnabled(false);
         m_fwdAction->setEnabled(false);
-        m_recAction->setEnabled(true);
         m_stopAction->setEnabled(false);
         m_playAction->setEnabled(false);
         if (KdenliveSettings::rmd_path().isEmpty()) {
@@ -208,30 +246,23 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
         //video_frame->setText(i18n("Press record button\nto start screen capture"));
         break;
     case VIDEO4LINUX:
-        m_discAction->setEnabled(false);
-        m_rewAction->setEnabled(false);
-        m_fwdAction->setEnabled(false);
-        m_recAction->setEnabled(true);
         m_stopAction->setEnabled(false);
         m_playAction->setEnabled(true);
         checkDeviceAvailability();
         break;
     case BLACKMAGIC:
-        createBlackmagicDevice();
-        m_recAction->setEnabled(false);
         m_stopAction->setEnabled(false);
         m_playAction->setEnabled(true);
-
         capturefile = m_capturePath;
         if (!capturefile.endsWith("/")) capturefile.append("/");
-        capturename = KdenliveSettings::hdmifilename();
-        capturename.append("xxx.raw");
+        capturename = KdenliveSettings::decklink_filename();
+        capturename.append("xxx.");
+        capturename.append(KdenliveSettings::decklink_extension());
         capturefile.append(capturename);
         video_frame->setPixmap(mergeSideBySide(KIcon("camera-photo").pixmap(QSize(50, 50)), i18n("Plug your camcorder and\npress play button\nto start preview.\nFiles will be saved in:\n%1", capturefile)));
         break;
     default: // FIREWIRE
         m_discAction->setEnabled(true);
-        m_recAction->setEnabled(false);
         m_stopAction->setEnabled(false);
         m_playAction->setEnabled(false);
         m_rewAction->setEnabled(false);
@@ -269,29 +300,12 @@ void RecMonitor::slotVideoDeviceChanged(int ix)
     }
 }
 
-void RecMonitor::createBlackmagicDevice()
-{
-    //video_capture->setVisible(true);
-    if (m_bmCapture == NULL) {
-        QVBoxLayout *lay = new QVBoxLayout;
-        m_bmCapture = new BmdCaptureHandler(lay);
-        connect(m_bmCapture, SIGNAL(gotTimeCode(ulong)), this, SLOT(slotGotBlackMagicFrameNumber(ulong)));
-        connect(m_bmCapture, SIGNAL(gotMessage(const QString &)), this, SLOT(slotGotBlackmagicMessage(const QString &)));
-        video_capture->setLayout(lay);
-    }
-}
-
-void RecMonitor::slotGotBlackmagicFrameNumber(ulong ix)
-{
-    m_dvinfo.setText(QString::number(ix));
-}
-
-void RecMonitor::slotGotBlackmagicMessage(const QString &message)
+void RecMonitor::slotSetInfoMessage(const QString &message)
 {
     m_logger.insertItem(0, message);
 }
 
-QPixmap RecMonitor::mergeSideBySide(const QPixmap& pix, const QString txt)
+QPixmap RecMonitor::mergeSideBySide(const QPixmap& pix, const QString &txt)
 {
     QPainter p;
     QRect r = QApplication::fontMetrics().boundingRect(QRect(0, 0, video_frame->width(), video_frame->height()), Qt::AlignLeft, txt);
@@ -316,9 +330,9 @@ void RecMonitor::checkDeviceAvailability()
         m_playAction->setEnabled(false);
         m_recAction->setEnabled(false);
         video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice())));
-        //video_frame->setText(i18n("Cannot read from device %1\nPlease check drivers and access rights.", KdenliveSettings::video4vdevice()));
-    } else //video_frame->setText(i18n("Press play or record button\nto start video capture"));
+    } else {
         video_frame->setPixmap(mergeSideBySide(KIcon("camera-web").pixmap(QSize(50, 50)), i18n("Press play or record button\nto start video capture\nFiles will be saved in:\n%1", m_capturePath)));
+    }
 }
 
 void RecMonitor::slotDisconnect()
@@ -327,7 +341,7 @@ void RecMonitor::slotDisconnect()
         m_captureTime = KDateTime::currentLocalDateTime();
         kDebug() << "CURRENT TIME: " << m_captureTime.toString();
         m_didCapture = false;
-        slotStartCapture(false);
+        slotStartPreview(false);
         m_discAction->setIcon(KIcon("network-disconnect"));
         m_discAction->setText(i18n("Disconnect"));
         m_recAction->setEnabled(true);
@@ -356,31 +370,45 @@ void RecMonitor::slotForward()
 void RecMonitor::slotStopCapture()
 {
     // stop capture
-    video_capture->setHidden(true);
-    video_frame->setHidden(false);
+    if (!m_isCapturing && !m_isPlaying) return;
+    m_videoBox->setHidden(true);
     switch (device_selector->currentIndex()) {
     case FIREWIRE:
         m_captureProcess->write("\e", 2);
         m_playAction->setIcon(m_playIcon);
         m_isPlaying = false;
         break;
-    case VIDEO4LINUX:
     case SCREENGRAB:
         m_captureProcess->write("q\n", 3);
+        m_captureProcess->terminate();
+        video_frame->setText(i18n("Encoding captured video..."));
         QTimer::singleShot(1000, m_captureProcess, SLOT(kill()));
         break;
+    case VIDEO4LINUX:
     case BLACKMAGIC:
-        m_bmCapture->stopPreview();
+        if (m_captureDevice) {
+            m_captureDevice->stop();
+        }
+        recording_preview->setEnabled(true);
+        m_isCapturing = false;
+        m_isPlaying = false;
         m_playAction->setEnabled(true);
         m_stopAction->setEnabled(false);
-        m_recAction->setEnabled(false);
+        m_recAction->setEnabled(true);
+        slotSetInfoMessage(i18n("Capture stopped"));
+        m_isCapturing = false;
+        m_recAction->setChecked(false);
+        if (autoaddbox->isChecked() && !m_captureFile.isEmpty() && QFile::exists(m_captureFile.path())) {
+            emit addProjectClip(m_captureFile);
+            m_captureFile.clear();
+        }
         break;
     default:
         break;
     }
 }
 
-void RecMonitor::slotStartCapture(bool play)
+void RecMonitor::slotStartPreview(bool play)
 {
     if (m_captureProcess->state() != QProcess::NotRunning) {
         if (device_selector->currentIndex() == FIREWIRE) {
@@ -401,11 +429,13 @@ void RecMonitor::slotStartCapture(bool play)
     m_displayArgs.clear();
     m_isPlaying = false;
     QString capturename = KdenliveSettings::dvgrabfilename();
+    QString path;
+    MltVideoProfile profile;
+    QString producer;
     QStringList dvargs = KdenliveSettings::dvgrabextra().simplified().split(" ", QString::SkipEmptyParts);
-    video_capture->setVisible(device_selector->currentIndex() == BLACKMAGIC);
-    video_frame->setHidden(device_selector->currentIndex() == BLACKMAGIC);
-
-    switch (device_selector->currentIndex()) {
+    int ix = device_selector->currentIndex();
+    m_videoBox->setHidden(ix != VIDEO4LINUX && ix != BLACKMAGIC);
+    switch (ix) {
     case FIREWIRE:
         switch (KdenliveSettings::firewireformat()) {
         case 0:
@@ -449,23 +479,45 @@ void RecMonitor::slotStartCapture(bool play)
         m_discAction->setEnabled(true);
         break;
     case VIDEO4LINUX:
-        m_captureArgs << KdenliveSettings::video4capture().simplified().split(' ') << KdenliveSettings::video4encoding().simplified().split(' ') << "-f" << KdenliveSettings::video4container() << "-";
-        m_displayArgs << "-f" << KdenliveSettings::video4container() << "-x" << QString::number(video_frame->width()) << "-y" << QString::number(video_frame->height()) << "-";
-        m_captureProcess->setStandardOutputProcess(m_displayProcess);
-        kDebug() << "Capture: Running ffmpeg " << m_captureArgs.join(" ");
-        m_captureProcess->start("ffmpeg", m_captureArgs);
+        path = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+        m_manager->activateMonitor("record");
+        buildMltDevice(path);
+        profile = ProfilesDialog::getVideoProfile(path);
+        producer = QString("avformat-novalidate:video4linux2:%1?width:%2&height:%3&frame_rate:%4").arg(KdenliveSettings::video4vdevice()).arg(profile.width).arg(profile.height).arg((double) profile.frame_rate_num / profile.frame_rate_den);
+        if (!m_captureDevice->slotStartPreview(producer)) {
+            // v4l capture failed to start
+            video_frame->setText(i18n("Failed to start Video4Linux,\ncheck your parameters..."));
+            m_videoBox->setHidden(true);
+            
+        } else {
+            m_playAction->setEnabled(false);
+            m_stopAction->setEnabled(true);
+            m_isPlaying = true;
+        }
+        
         break;
     case BLACKMAGIC:
-        m_bmCapture->startPreview(KdenliveSettings::hdmi_capturedevice(), KdenliveSettings::hdmi_capturemode());
-        m_playAction->setEnabled(false);
-        m_stopAction->setEnabled(true);
-        m_recAction->setEnabled(true);
+        path = KdenliveSettings::current_profile();
+        m_manager->activateMonitor("record");
+        buildMltDevice(path);
+        profile = ProfilesDialog::getVideoProfile(path);
+        producer = QString("decklink:%1").arg(KdenliveSettings::decklink_capturedevice());
+        if (!m_captureDevice->slotStartPreview(producer)) {
+            // v4l capture failed to start
+            video_frame->setText(i18n("Failed to start Decklink,\ncheck your parameters..."));
+            m_videoBox->setHidden(true);
+            
+        } else {
+            m_playAction->setEnabled(false);
+            m_stopAction->setEnabled(true);
+            m_isPlaying = true;
+        }
         break;
     default:
         break;
     }
 
-    if (device_selector->currentIndex() == FIREWIRE || device_selector->currentIndex() == VIDEO4LINUX) {
+    if (device_selector->currentIndex() == FIREWIRE) {
         kDebug() << "Capture: Running ffplay " << m_displayArgs.join(" ");
         m_displayProcess->start("ffplay", m_displayArgs);
         video_frame->setText(i18n("Initialising..."));
@@ -476,48 +528,12 @@ void RecMonitor::slotStartCapture(bool play)
 
 void RecMonitor::slotRecord()
 {
-    if (device_selector->currentIndex() == BLACKMAGIC) {
-        if (m_blackmagicCapturing) {
-            // We are capturing, stop it
-            m_bmCapture->stopCapture();
-            m_blackmagicCapturing = false;
-        } else {
-            // Start capture, get capture filename first
-            QString path = m_capturePath;
-            if (!path.endsWith("/")) path.append("/");
-            path.append(KdenliveSettings::hdmifilename());
-            m_bmCapture->startCapture(path);
-            m_blackmagicCapturing = true;
-        }
-        return;
-    }
-
     if (m_captureProcess->state() == QProcess::NotRunning && device_selector->currentIndex() == FIREWIRE) {
-        slotStartCapture();
+        slotStartPreview();
     }
     if (m_isCapturing) {
-        switch (device_selector->currentIndex()) {
-        case FIREWIRE:
-            m_captureProcess->write("\e", 2);
-            m_playAction->setIcon(m_playIcon);
-            m_isCapturing = false;
-            m_isPlaying = false;
-            m_recAction->setChecked(false);
-            break;
-        case VIDEO4LINUX:
-            m_captureProcess->terminate();
-            slotStopCapture();
-            //m_isCapturing = false;
-            QTimer::singleShot(1000, this, SLOT(slotStartCapture()));
-            break;
-        case SCREENGRAB:
-            //captureProcess->write("q\n", 3);
-            m_captureProcess->terminate();
-            video_frame->setText(i18n("Encoding captured video..."));
-            // in case ffmpeg doesn't exit with the 'q' command, kill it one second later
-            //QTimer::singleShot(1000, captureProcess, SLOT(kill()));
-            break;
-        }
+        // User stopped capture
+        slotStopCapture();
         return;
     } else if (device_selector->currentIndex() == FIREWIRE) {
         m_isCapturing = true;
@@ -529,15 +545,17 @@ void RecMonitor::slotRecord()
         return;
     }
     if (m_captureProcess->state() == QProcess::NotRunning) {
+        m_logger.clear();
         m_recAction->setChecked(true);
-        QString extension = "mp4";
+        QString extension = "mpg";
         if (device_selector->currentIndex() == SCREENGRAB) extension = "ogv"; //KdenliveSettings::screengrabextension();
-        else if (device_selector->currentIndex() == VIDEO4LINUX) extension = KdenliveSettings::video4extension();
-        QString path = m_capturePath + "/capture0000." + extension;
+        else if (device_selector->currentIndex() == VIDEO4LINUX) extension = KdenliveSettings::v4l_extension();
+        else if (device_selector->currentIndex() == BLACKMAGIC) extension = KdenliveSettings::decklink_extension();
+        QString path = KUrl(m_capturePath).path(KUrl::AddTrailingSlash) + "capture0000." + extension;
         int i = 1;
         while (QFile::exists(path)) {
             QString num = QString::number(i).rightJustified(4, '0', false);
-            path = m_capturePath + "/capture" + num + '.' + extension;
+            path = KUrl(m_capturePath).path(KUrl::AddTrailingSlash) + "capture" + num + '.' + extension;
             i++;
         }
         m_captureFile = KUrl(path);
@@ -545,17 +563,105 @@ void RecMonitor::slotRecord()
         m_captureArgs.clear();
         m_displayArgs.clear();
         QString args;
+        QString playlist;
+        QString v4lparameters;
+        MltVideoProfile profile;
         QString capturename = KdenliveSettings::dvgrabfilename();
         if (capturename.isEmpty()) capturename = "capture";
 
         switch (device_selector->currentIndex()) {
         case VIDEO4LINUX:
-            m_captureArgs << KdenliveSettings::video4capture().simplified().split(' ') << KdenliveSettings::video4encoding().simplified().split(' ') << "-y" << m_captureFile.path() << "-f" << KdenliveSettings::video4container() << "-acodec" << KdenliveSettings::video4acodec() << "-vcodec" << KdenliveSettings::video4vcodec() << "-";
-            m_displayArgs << "-f" << KdenliveSettings::video4container() << "-x" << QString::number(video_frame->width()) << "-y" << QString::number(video_frame->height()) << "-";
-            m_captureProcess->setStandardOutputProcess(m_displayProcess);
-            kDebug() << "Capture: Running ffmpeg " << m_captureArgs.join(" ");
-            m_captureProcess->start("ffmpeg", m_captureArgs);
+            path = KStandardDirs::locateLocal("appdata", "profiles/video4linux");
+            profile = ProfilesDialog::getVideoProfile(path);
+            m_videoBox->setRatio((double) profile.display_aspect_num / profile.display_aspect_den);
+            buildMltDevice(path);
+            playlist = QString("<mlt title=\"capture\"><producer id=\"producer0\" in=\"0\" out=\"99999\"><property name=\"mlt_type\">producer</property><property name=\"length\">100000</property><property name=\"eof\">pause</property><property name=\"resource\">video4linux2:%1?width:%2&amp;height:%3&amp;frame_rate:%4</property><property name=\"mlt_service\">avformat-novalidate</property></producer><playlist id=\"playlist0\"><entry producer=\"producer0\" in=\"0\" out=\"99999\"/></playlist>").arg(KdenliveSettings::video4vdevice()).arg(profile.width).arg(profile.height).arg((double) profile.frame_rate_num / profile.frame_rate_den);
+
+            v4lparameters = KdenliveSettings::v4l_parameters();
+
+            // Add alsa audio capture
+            if (KdenliveSettings::v4l_captureaudio()) {
+                playlist.append(QString("<producer id=\"producer1\" in=\"0\" out=\"99999\"><property name=\"mlt_type\">producer</property><property name=\"length\">100000</property><property name=\"eof\">pause</property><property name=\"resource\">alsa:%5</property><property name=\"audio_index\">0</property><property name=\"video_index\">-1</property><property name=\"mlt_service\">avformat</property></producer><playlist id=\"playlist1\"><entry producer=\"producer1\" in=\"0\" out=\"99999\"/></playlist>").arg(KdenliveSettings::v4l_alsadevicename()));
+            }
+            else {
+                // if we do not want audio, make sure that we don't have audio encoding parameters
+                // this is required otherwise the MLT avformat consumer will not close properly
+                if (v4lparameters.contains("acodec")) {
+                    QString endParam = v4lparameters.section("acodec", 1);
+                    int vcodec = endParam.indexOf(" vcodec");
+                    int format = endParam.indexOf(" f=");
+                    int cutPosition = -1;
+                    if (vcodec > -1) {
+                        if (format  > -1) {
+                            cutPosition = qMin(vcodec, format);
+                        }
+                        else cutPosition = vcodec;
+                    }
+                    else if (format  > -1) {
+                        cutPosition = format;
+                    }
+                    else {
+                        // nothing interesting in end params
+                        endParam.clear();
+                    }
+                    if (cutPosition > -1) {
+                        endParam.remove(0, cutPosition);
+                    }
+                    v4lparameters = QString(v4lparameters.section("acodec", 0, 0) + "an=1 " + endParam).simplified();
+                }
+            }
+            
+
+            playlist.append("<tractor id=\"tractor0\" title=\"video0\" global_feed=\"1\" in=\"0\" out=\"99999\">");
+
+            playlist.append("<track producer=\"playlist0\"/>");            
+
+            // Audio mix
+            if (KdenliveSettings::v4l_captureaudio()) {
+                playlist.append("<track producer=\"playlist1\"/>");
+                playlist.append("<transition id=\"transition0\" in=\"0\" out=\"0\"><property name=\"a_track\">0</property><property name=\"b_track\">1</property><property name=\"mlt_type\">transition</property><property name=\"mlt_service\">mix</property></transition>");
+            }
+
+            playlist.append("</tractor></mlt>");
+
+            if (m_captureDevice->slotStartCapture(v4lparameters, m_captureFile.path(), playlist, recording_preview->currentIndex())) {
+                m_videoBox->setHidden(false);
+                m_isCapturing = true;
+                m_recAction->setEnabled(false);
+                m_stopAction->setEnabled(true);
+                recording_preview->setEnabled(false);
+            }
+            else {
+                video_frame->setText(i18n("Failed to start Video4Linux,\ncheck your parameters..."));                
+                m_videoBox->setHidden(true);
+                m_isCapturing = false;
+            }
             break;
+            
+        case BLACKMAGIC:
+            path = KdenliveSettings::current_profile();
+            profile = ProfilesDialog::getVideoProfile(path);
+            m_videoBox->setRatio((double) profile.display_aspect_num / profile.display_aspect_den);
+            buildMltDevice(path);
+               
+            playlist = QString("<producer id=\"producer0\" in=\"0\" out=\"99999\"><property name=\"mlt_type\">producer</property><property name=\"length\">100000</property><property name=\"eof\">pause</property><property name=\"resource\">%1</property><property name=\"mlt_service\">decklink</property></producer>").arg(KdenliveSettings::decklink_capturedevice());
+
+            if (m_captureDevice->slotStartCapture(KdenliveSettings::decklink_parameters(), m_captureFile.path(), QString("decklink:%1").arg(KdenliveSettings::decklink_capturedevice()), recording_preview->currentIndex(), false)) {
+                m_videoBox->setHidden(false);
+                m_isCapturing = true;
+                slotSetInfoMessage(i18n("Capturing to %1", m_captureFile.fileName()));
+                m_recAction->setEnabled(false);
+                m_stopAction->setEnabled(true);
+                recording_preview->setEnabled(false);
+            }
+            else {
+                video_frame->setText(i18n("Failed to start Decklink,\ncheck your parameters..."));
+                slotSetInfoMessage(i18n("Failed to start capture"));
+                m_videoBox->setHidden(true);
+                m_isCapturing = false;
+            }
+            break;
+            
         case SCREENGRAB:
             switch (KdenliveSettings::rmd_capture_type()) {
             case 0:
@@ -606,7 +712,7 @@ void RecMonitor::slotRecord()
         }
 
 
-        if (device_selector->currentIndex() != SCREENGRAB) {
+        if (device_selector->currentIndex() == FIREWIRE) {
             m_isCapturing = true;
             kDebug() << "Capture: Running ffplay " << m_displayArgs.join(" ");
             m_displayProcess->start("ffplay", m_displayArgs);
@@ -654,7 +760,10 @@ void RecMonitor::slotProcessStatus(QProcess::ProcessState status)
     if (status == QProcess::NotRunning) {
         m_displayProcess->kill();
         if (m_isCapturing && device_selector->currentIndex() != FIREWIRE)
-            if (autoaddbox->isChecked() && QFile::exists(m_captureFile.path())) emit addProjectClip(m_captureFile);
+            if (autoaddbox->isChecked() && !m_captureFile.isEmpty() && QFile::exists(m_captureFile.path())) {
+                emit addProjectClip(m_captureFile);
+                m_captureFile.clear();
+            }
         if (device_selector->currentIndex() == FIREWIRE) {
             m_discAction->setIcon(KIcon("network-connect"));
             m_discAction->setText(i18n("Connect"));
@@ -721,7 +830,19 @@ void RecMonitor::manageCapturedFiles()
         KUrl url = KUrl(dir.filePath(name));
         if (KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, this)) {
             KFileItem file(KFileItem::Unknown, KFileItem::Unknown, url, true);
-            if (file.time(KFileItem::ModificationTime) > m_captureTime) capturedFiles.append(url);
+            if (file.time(KFileItem::ModificationTime) > m_captureTime) {
+                // The file was captured in the last batch
+                if (url.fileName().contains(':')) {
+                    // Several dvgrab options (--timecode,...) use : in the file name, which is
+                    // not supported by MLT, so rename them
+                    QString newUrl = url.directory(KUrl::AppendTrailingSlash) + url.fileName().replace(':', '_');
+                    if (QFile::rename(url.path(), newUrl)) {
+                        url = KUrl(newUrl);
+                    }
+                    
+                }
+                capturedFiles.append(url);
+            }
         }
     }
     kDebug() << "Found : " << capturedFiles.count() << " new capture files";
@@ -730,10 +851,7 @@ void RecMonitor::manageCapturedFiles()
     if (capturedFiles.count() > 0) {
         ManageCapturesDialog *d = new ManageCapturesDialog(capturedFiles, this);
         if (d->exec() == QDialog::Accepted) {
-            capturedFiles = d->importFiles();
-            foreach(const KUrl & url, capturedFiles) {
-                emit addProjectClip(url);
-            }
+            emit addProjectClipList(d->importFiles());
         }
         delete d;
     }
@@ -751,7 +869,7 @@ void RecMonitor::slotUpdateFreeSpace()
 {
 #if KDE_IS_VERSION(4,2,0)
     KDiskFreeSpaceInfo info = KDiskFreeSpaceInfo::freeSpaceInfo(m_capturePath);
-    if (info.isValid()) {
+    if (info.isValid() && info.size() > 0) {
         m_freeSpace->setValue(100 * info.used() / info.size());
         m_freeSpace->setText(i18n("Free space: %1", KIO::convertSize(info.available())));
         m_freeSpace->update();
@@ -759,23 +877,6 @@ void RecMonitor::slotUpdateFreeSpace()
 #endif
 }
 
-void RecMonitor::activateRecMonitor()
-{
-    //if (!m_isActive) m_monitorManager->activateRecMonitor(m_name);
-}
-
-void RecMonitor::stop()
-{
-    m_isActive = false;
-
-}
-
-void RecMonitor::start()
-{
-    m_isActive = true;
-
-}
-
 void RecMonitor::refreshRecMonitor(bool visible)
 {
     if (visible) {
@@ -799,5 +900,37 @@ void RecMonitor::slotReadDvgrabInfo()
     m_dvinfo.updateGeometry();
 }
 
+AbstractRender *RecMonitor::abstractRender()
+{
+    return m_captureDevice;
+}
+
+
+void RecMonitor::analyseFrames(bool analyse)
+{
+    m_analyse = analyse;
+    if (m_captureDevice) m_captureDevice->sendFrameForAnalysis = analyse;
+}
+
+void RecMonitor::slotDroppedFrames(int dropped)
+{
+    slotSetInfoMessage(i18n("%1 dropped frames", dropped));
+}
+
+void RecMonitor::buildMltDevice(const QString &path)
+{
+    if (m_captureDevice == NULL) {
+        m_captureDevice = new MltDeviceCapture(path, m_videoBox, this);
+        connect(m_captureDevice, SIGNAL(droppedFrames(int)), this, SLOT(slotDroppedFrames(int)));
+        m_captureDevice->sendFrameForAnalysis = m_analyse;
+        m_manager->updateScopeSource();
+    }
+}
+
+void RecMonitor::slotChangeRecordingPreview(int ix)
+{
+    KdenliveSettings::setRecording_preview(ix);
+}
+
 #include "recmonitor.moc"
 
