@@ -124,6 +124,7 @@ TrackView::~TrackView()
 {
     delete m_ruler;
     delete m_trackview;
+    delete m_scene;
 }
 
 //virtual
@@ -189,12 +190,7 @@ void TrackView::parseDocument(QDomDocument doc)
 {
     //int cursorPos = 0;
     m_documentErrors.clear();
-
-    //kDebug() << "//// DOCUMENT: " << doc.toString();
-    /*QDomNode props = doc.elementsByTagName("properties").item(0);
-    if (!props.isNull()) {
-        cursorPos = props.toElement().attribute("timeline_position").toInt();
-    }*/
+    m_replacementProducerIds.clear();
 
     // parse project tracks
     QDomElement mlt = doc.firstChildElement("mlt");
@@ -215,21 +211,6 @@ void TrackView::parseDocument(QDomDocument doc)
         QDomNode n = producers.item(i);
         e = n.toElement();
 
-        /*
-        // Check for invalid markup
-        QDomNodeList params = e.elementsByTagName("property");
-        for (int j = 0; j < params.count(); j++) {
-            QDomElement p = params.item(j).toElement();
-            if (p.attribute("name") == "markup") {
-         QString val = p.text().toUtf8().data();
-         kDebug()<<"//FOUND MARKUP, VAL: "<<val;
-         //e.setAttribute("value", value);
-         n.removeChild(params.item(j));
-         break;
-            }
-        }
-        */
-
         if (e.hasAttribute("in") == false && e.hasAttribute("out") == false) continue;
         int in = e.attribute("in").toInt();
         int out = e.attribute("out").toInt();
@@ -271,7 +252,7 @@ void TrackView::parseDocument(QDomDocument doc)
                 m_doc->switchTrackAudio(i - 1, true);
             }
 
-            trackduration = slotAddProjectTrack(pos, p, m_doc->isTrackLocked(i - 1));
+            trackduration = slotAddProjectTrack(pos, p, m_doc->isTrackLocked(i - 1), producers);
             pos--;
             //kDebug() << " PRO DUR: " << trackduration << ", TRACK DUR: " << duration;
             if (trackduration > duration) duration = trackduration;
@@ -346,15 +327,13 @@ void TrackView::parseDocument(QDomDocument doc)
                 // When adding composite transition, check if it is a wipe transition
                 if (mlt_geometry.count(';') == 1) {
                     mlt_geometry.remove(QChar('%'), Qt::CaseInsensitive);
-                    mlt_geometry.replace(QChar('x'), QChar(','), Qt::CaseInsensitive);
-                    QString start = mlt_geometry.section(';', 0, 0);
-                    start = start.section(':', 0, 1);
-                    start.replace(QChar(':'), QChar(','), Qt::CaseInsensitive);
-                    QString end = mlt_geometry.section('=', 1, 1);
-                    end = end.section(':', 0, 1);
-                    end.replace(QChar(':'), QChar(','), Qt::CaseInsensitive);
-                    start.append(',' + end);
-                    QStringList numbers = start.split(',', QString::SkipEmptyParts);
+                    mlt_geometry.replace(QChar('x'), QChar(':'), Qt::CaseInsensitive);
+                    mlt_geometry.replace(QChar(','), QChar(':'), Qt::CaseInsensitive);
+                    mlt_geometry.replace(QChar('/'), QChar(':'), Qt::CaseInsensitive);
+                    
+                    QString start = mlt_geometry.section('=', 0, 0).section(':', 0, -2) + ':';
+                    start.append(mlt_geometry.section('=', 1, 1).section(':', 0, -2));
+                    QStringList numbers = start.split(':', QString::SkipEmptyParts);
                     bool isWipeTransition = true;
                     int checkNumber;
                     for (int i = 0; i < numbers.size(); ++i) {
@@ -382,13 +361,15 @@ void TrackView::parseDocument(QDomDocument doc)
                                 if (!e.isNull() && e.attribute("tag") == paramName) {
                                     if (e.attribute("type") == "double") {
                                         QString factor = e.attribute("factor", "1");
-                                        if (factor != "1") {
+                                        double offset = e.attribute("offset", "0").toDouble();
+                                        if (factor != "1" || offset != 0) {
                                             double fact;
-                                            if (factor.startsWith('%')) {
+                                            if (factor.contains('%')) {
                                                 fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
-                                            } else fact = factor.toDouble();
-                                            double val = paramValue.toDouble() * fact;
-                                            paramValue = QString::number(val);
+                                            } else {
+                                                fact = factor.toDouble();
+                                            }
+                                            paramValue = QLocale().toString(offset + paramValue.toDouble() * fact);
                                         }
                                     }
                                     e.setAttribute("value", paramValue);
@@ -413,7 +394,7 @@ void TrackView::parseDocument(QDomDocument doc)
                 kDebug() << "///// REMOVED INVALID TRANSITION: " << e.attribute("id");
                 tractor.removeChild(transitions.item(i));
                 i--;
-            } else {
+            } else if (m_trackview->canBePastedTo(transitionInfo, TRANSITIONWIDGET)) {
                 Transition *tr = new Transition(transitionInfo, a_track, m_doc->fps(), base, isAutomatic);
                 if (forceTrack) tr->setForcedTrack(true, a_track);
                 m_scene->addItem(tr);
@@ -421,10 +402,13 @@ void TrackView::parseDocument(QDomDocument doc)
                     tr->setItemLocked(true);
                 }
             }
+            else {
+                m_documentErrors.append(i18n("Removed overlapping transition: (%1, %2, %3)", e.attribute("id"), mlt_service, transitionId) + '\n');
+                tractor.removeChild(transitions.item(i));
+                i--;
+            }
         }
     }
-
-
     QDomElement infoXml = mlt.firstChildElement("kdenlivedoc");
 
     // Add guides
@@ -447,7 +431,7 @@ void TrackView::parseDocument(QDomDocument doc)
 
     slotRebuildTrackHeaders();
     if (!m_documentErrors.isNull()) KMessageBox::sorry(this, m_documentErrors);
-    if (infoXml.hasAttribute("upgraded")) {
+    if (infoXml.hasAttribute("upgraded") || infoXml.hasAttribute("modified")) {
         // Our document was upgraded, create a backup copy just in case
         QString baseFile = m_doc->url().path().section(".kdenlive", 0, 0);
         int ct = 0;
@@ -456,8 +440,13 @@ void TrackView::parseDocument(QDomDocument doc)
             ct++;
             backupFile = baseFile + "_backup" + QString::number(ct) + ".kdenlive";
         }
+        QString message;
+        if (infoXml.hasAttribute("upgraded"))
+            message = i18n("Your project file was upgraded to the latest Kdenlive document version.\nTo make sure you don't lose data, a backup copy called %1 was created.", backupFile);
+        else
+            message = i18n("Your project file was modified by Kdenlive.\nTo make sure you don't lose data, a backup copy called %1 was created.", backupFile);
         if (KIO::NetAccess::file_copy(m_doc->url(), KUrl(backupFile), this))
-            KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version.\nTo make sure you don't lose data, a backup copy called %1 was created.", backupFile));
+            KMessageBox::information(this, message);
         else
             KMessageBox::information(this, i18n("Your project file was upgraded to the latest Kdenlive document version, but it was not possible to create a backup copy.", backupFile));
     }
@@ -483,7 +472,7 @@ void TrackView::moveCursorPos(int pos)
 void TrackView::slotChangeZoom(int horizontal, int vertical)
 {
     m_ruler->setPixelPerMark(horizontal);
-    m_scale = (double) FRAME_SIZE / m_ruler->comboScale[horizontal];
+    m_scale = (double) m_trackview->getFrameWidth() / m_ruler->comboScale[horizontal];
 
     if (vertical == -1) {
         // user called zoom
@@ -501,7 +490,7 @@ void TrackView::slotChangeZoom(int horizontal, int vertical)
 
 int TrackView::fitZoom() const
 {
-    int zoom = (int)((duration() + 20 / m_scale) * FRAME_SIZE / m_trackview->width());
+    int zoom = (int)((duration() + 20 / m_scale) * m_trackview->getFrameWidth() / m_trackview->width());
     int i;
     for (i = 0; i < 13; i++)
         if (m_ruler->comboScale[i] > zoom) break;
@@ -545,6 +534,16 @@ void TrackView::slotRebuildTrackHeaders()
     int height = KdenliveSettings::trackheight() * m_scene->scale().y() - 1;
     HeaderTrack *header = NULL;
     QFrame *frame = NULL;
+
+    QPalette p = palette();
+    KColorScheme scheme(p.currentColorGroup(), KColorScheme::View, KSharedConfig::openConfig(KdenliveSettings::colortheme()));
+    QColor norm = scheme.shade(scheme.background(KColorScheme::ActiveBackground).color(), KColorScheme::MidShade);
+    p.setColor(QPalette::Button, norm);
+
+    QColor col = scheme.background().color();
+    QColor col2 = scheme.foreground().color();
+    headers_container->setStyleSheet(QString("QLineEdit { background-color: transparent;color: rgb(%4, %5, %6);} QLineEdit:hover{ background-color: rgb(%1, %2, %3);} QLineEdit:focus { background-color: rgb(%1, %2, %3);}").arg(col.red()).arg(col.green()).arg(col.blue()).arg(col2.red()).arg(col2.green()).arg(col2.blue()));
+    
     for (int i = 0; i < max; i++) {
         frame = new QFrame(headers_container);
         frame->setFrameStyle(QFrame::HLine);
@@ -552,6 +551,7 @@ void TrackView::slotRebuildTrackHeaders()
         headers_container->layout()->addWidget(frame);
         TrackInfo info = list.at(max - i - 1);
         header = new HeaderTrack(i, info, height, headers_container);
+        header->setPalette(p);
         header->setSelectedIndex(m_trackview->selectedTrack());
         connect(header, SIGNAL(switchTrackVideo(int)), m_trackview, SLOT(slotSwitchTrackVideo(int)));
         connect(header, SIGNAL(switchTrackAudio(int)), m_trackview, SLOT(slotSwitchTrackAudio(int)));
@@ -581,10 +581,12 @@ void TrackView::adjustTrackHeaders()
     }
 }
 
-int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
+int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked, QDomNodeList producers)
 {
     // parse track
     int position = 0;
+    QMap <QString, QString> producerReplacementIds;
+    int frame_width = m_trackview->getFrameWidth();
     QDomNodeList children = xml.childNodes();
     for (int nodeindex = 0; nodeindex < children.count(); nodeindex++) {
         QDomNode n = children.item(nodeindex);
@@ -602,43 +604,117 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
                 continue;
             }
             QString idString = elem.attribute("producer");
+            if (producerReplacementIds.contains(idString)) {
+                // replace id
+                elem.setAttribute("producer", producerReplacementIds.value(idString));
+                idString = elem.attribute("producer");
+            }
             QString id = idString;
             double speed = 1.0;
             int strobe = 1;
             if (idString.startsWith("slowmotion")) {
+                QLocale locale;
                 id = idString.section(':', 1, 1);
-                speed = idString.section(':', 2, 2).toDouble();
+                speed = locale.toDouble(idString.section(':', 2, 2));
                 strobe = idString.section(':', 3, 3).toInt();
                 if (strobe == 0) strobe = 1;
-            } else id = id.section('_', 0, 0);
+            }
+            id = id.section('_', 0, 0);
             DocClipBase *clip = m_doc->clipManager()->getClipById(id);
             if (clip == NULL) {
                 // The clip in playlist was not listed in the kdenlive producers,
                 // something went wrong, repair required.
                 kWarning() << "CANNOT INSERT CLIP " << id;
-
-                clip = getMissingProducer(id);
-                if (!clip) {
+                QString docRoot = m_doc->toXml().documentElement().attribute("root");
+                if (!docRoot.endsWith('/')) docRoot.append('/');
+                clip = getMissingProducer(idString);
+                if (clip) {
+                    // We found the original producer in Kdenlive's producers
+                    // Found correct producer
+                    m_documentErrors.append(i18n("Replaced wrong clip producer %1 with %2", id, clip->getId()) + '\n');
+                    QString prodId = clip->getId();
+                    if (clip->clipType() == PLAYLIST || clip->clipType() == AV || clip->clipType() == AUDIO) {
+                        // We need producer for the track
+                        prodId.append("_" + QString::number(ix));
+                    }
+                    elem.setAttribute("producer", prodId);
+                    producerReplacementIds.insert(idString, prodId);
+                    // now adjust the mlt producer
+                    bool found = false;
+                    for (int i = 0; i < producers.count(); i++) {
+                        QDomElement prod = producers.at(i).toElement();
+                        if (prod.attribute("id") == prodId) {
+                            // ok, producer already exists
+                            found = true;
+                            break;
+                        }
+                    }
+                    if (!found) {
+                        for (int i = 0; i < producers.count(); i++) {
+                            QDomElement prod = producers.at(i).toElement();
+                            if (prod.attribute("id") == idString) {
+                                prod.setAttribute("id", prodId);
+                                m_replacementProducerIds.insert(idString, prodId);
+                                found = true;
+                                break;
+                            }
+                        }
+                    }
+                    if (!found) {
+                        // We didn't find the producer for this track, find producer for another track and duplicate
+                        for (int i = 0; i < producers.count(); i++) {
+                            QDomElement prod = producers.at(i).toElement();
+                            QString mltProdId = prod.attribute("id");
+                            if (mltProdId == prodId || mltProdId.startsWith(prodId + "_")) {
+                                // Found parent producer, clone it
+                                QDomElement clone = prod.cloneNode().toElement();
+                                clone.setAttribute("id", prodId);
+                                m_doc->toXml().documentElement().insertBefore(clone, xml);
+                                break;
+                            }
+                        }
+                    }                    
+                }
+                else {
                     // We cannot find the producer, something is really wrong, add
                     // placeholder color clip
                     QDomDocument doc;
                     QDomElement producerXml = doc.createElement("producer");
                     doc.appendChild(producerXml);
-                    producerXml.setAttribute("colour", "0xff0000ff");
-                    producerXml.setAttribute("mlt_service", "colour");
-                    producerXml.setAttribute("length", "15000");
-                    producerXml.setAttribute("name", "INVALID");
-                    producerXml.setAttribute("type", COLOR);
-                    producerXml.setAttribute("id", id);
-                    clip = new DocClipBase(m_doc->clipManager(), doc.documentElement(), id);
-                    xml.insertBefore(producerXml, QDomNode());
-                    m_doc->clipManager()->addClip(clip);
-
-                    m_documentErrors.append(i18n("Broken clip producer %1", id) + '\n');
-                } else {
-                    // Found correct producer
-                    m_documentErrors.append(i18n("Replaced wrong clip producer %1 with %2", id, clip->getId()) + '\n');
-                    elem.setAttribute("producer", clip->getId());
+                    bool foundMltProd = false;
+                    for (int i = 0; i < producers.count(); i++) {
+                        QDomElement prod = producers.at(i).toElement();
+                        if (prod.attribute("id") == id) {
+                            QString service = EffectsList::property(prod, "mlt_service");
+                            QString type = EffectsList::property(prod, "mlt_type");
+                            QString resource = EffectsList::property(prod, "resource");
+                            if (!resource.startsWith('/') && service != "colour") {
+                                resource.prepend(docRoot);
+                                kDebug()<<"******************\nADJUSTED 1\n*************************";
+                            }
+                            QString length = EffectsList::property(prod, "length");
+                            producerXml.setAttribute("mlt_service", service);
+                            producerXml.setAttribute("mlt_type", type);
+                            producerXml.setAttribute("resource", resource);
+                            producerXml.setAttribute("duration", length);
+                            if (service == "colour") producerXml.setAttribute("type", COLOR);
+                            else if (service == "qimage" || service == "pixbuf") producerXml.setAttribute("type", IMAGE);
+                            else if (service == "kdenlivetitle") producerXml.setAttribute("type", TEXT);
+                            else producerXml.setAttribute("type", AV);
+                            clip = new DocClipBase(m_doc->clipManager(), doc.documentElement(), id);
+                            m_doc->clipManager()->addClip(clip);
+                            m_documentErrors.append(i18n("Broken clip producer %1, recreated base clip: %2", id, resource) + '\n');
+                            foundMltProd = true;
+                            break;
+                        }
+                    }
+                    if (!foundMltProd) {
+                        // Cannot recover, replace with blank
+                        int duration = elem.attribute("out").toInt() - elem.attribute("in").toInt();
+                        elem.setAttribute("length", duration);
+                        elem.setTagName("blank");
+                        m_documentErrors.append(i18n("Broken clip producer %1, removed from project", id) + '\n');
+                    }
                 }
                 m_doc->setModified(true);
             }
@@ -652,7 +728,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
 
                 clipinfo.track = ix;
                 //kDebug() << "// INSERTING CLIP: " << in << "x" << out << ", track: " << ix << ", ID: " << id << ", SCALE: " << m_scale << ", FPS: " << m_doc->fps();
-                ClipItem *item = new ClipItem(clip, clipinfo, m_doc->fps(), speed, strobe, false);
+                ClipItem *item = new ClipItem(clip, clipinfo, m_doc->fps(), speed, strobe, frame_width, false);
                 if (idString.endsWith("_video")) item->setVideoOnly(true);
                 else if (idString.endsWith("_audio")) item->setAudioOnly(true);
                 m_scene->addItem(item);
@@ -680,6 +756,7 @@ int TrackView::slotAddProjectTrack(int ix, QDomElement xml, bool locked)
 void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNode, ClipItem *clip, int trackIndex)
 {
     int effectNb = 0;
+    QLocale locale;
     for (int ix = 0; ix < effects.count(); ix++) {
         bool disableeffect = false;
         QDomElement effect = effects.at(ix).toElement();
@@ -689,7 +766,6 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
         QString effecttag;
         QString effectid;
         QString effectindex = QString::number(effectNb);
-        QString ladspaEffectFile;
         // Get effect tag & index
         for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
             // parse effect parameters
@@ -704,15 +780,6 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
             } else if (effectparam.attribute("name") == "kdenlive_ix") {
                 // Fix effects index
                 effectparam.firstChild().setNodeValue(effectindex);
-            } else if (effectparam.attribute("name") == "src") {
-                ladspaEffectFile = effectparam.text();
-                if (!QFile::exists(ladspaEffectFile)) {
-                    // If the ladspa effect file is missing, recreate it
-                    kDebug() << "// MISSING LADSPA FILE: " << ladspaEffectFile;
-                    ladspaEffectFile = m_doc->getLadspaFile();
-                    effectparam.firstChild().setNodeValue(ladspaEffectFile);
-                    kDebug() << "// ... REPLACED WITH: " << ladspaEffectFile;
-                }
             }
         }
         //kDebug() << "+ + CLIP EFF FND: " << effecttag << ", " << effectid << ", " << effectindex;
@@ -740,6 +807,7 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
                 QString factor;
                 QString starttag;
                 QString endtag;
+                double offset = 0;
                 QDomNodeList params = currenteffect.elementsByTagName("parameter");
                 for (int i = 0; i < params.count(); i++) {
                     QDomElement e = params.item(i).toElement();
@@ -747,6 +815,7 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
                         starttag = e.attribute("starttag", "start");
                         endtag = e.attribute("endtag", "end");
                         factor = e.attribute("factor", "1");
+                        offset = e.attribute("offset", "0").toDouble();
                         break;
                     }
                 }
@@ -756,23 +825,24 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
                 double startvalue = 0;
                 double endvalue = 0;
                 double fact;
-                if (factor.isEmpty()) fact = 1;
-                else if (factor.startsWith('%')) {
+                if (factor.contains('%')) {
                     fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
-                } else fact = factor.toDouble();
+                } else {
+                    fact = factor.toDouble();
+                }
                 for (QDomNode n3 = effect.firstChild(); !n3.isNull(); n3 = n3.nextSibling()) {
                     // parse effect parameters
                     QDomElement effectparam = n3.toElement();
                     if (effectparam.attribute("name") == starttag)
-                        startvalue = effectparam.text().toDouble() * fact;
+                        startvalue = offset + effectparam.text().toDouble() * fact;
                     if (effectparam.attribute("name") == endtag)
-                        endvalue = effectparam.text().toDouble() * fact;
+                        endvalue = offset + effectparam.text().toDouble() * fact;
                 }
                 // add first keyframe
                 if (effectout <= effectin) {
                     // there is only one keyframe
-                    keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';');
-                } else keyframes.append(QString::number(effectin) + ':' + QString::number(startvalue) + ';' + QString::number(effectout) + ':' + QString::number(endvalue) + ';');
+                    keyframes.append(QString::number(effectin) + ':' + locale.toString(startvalue) + ';');
+                } else keyframes.append(QString::number(effectin) + ':' + locale.toString(startvalue) + ';' + QString::number(effectout) + ':' + QString::number(endvalue) + ';');
                 QDomNode lastParsedEffect;
                 ix++;
                 QDomNode n2 = effects.at(ix);
@@ -792,12 +862,12 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
                             continueParsing = false;
                             break;
                         } else if (subeffectparam.attribute("name") == endtag) {
-                            endvalue = subeffectparam.text().toDouble() * fact;
+                            endvalue = offset + subeffectparam.text().toDouble() * fact;
                             break;
                         }
                     }
                     if (continueParsing) {
-                        keyframes.append(QString::number(effectout) + ':' + QString::number(endvalue) + ';');
+                        keyframes.append(QString::number(effectout) + ':' + locale.toString(endvalue) + ';');
                         ix++;
                     }
                 }
@@ -832,40 +902,37 @@ void TrackView::slotAddProjectEffects(QDomNodeList effects, QDomElement parentNo
                 for (int k = 0; k < clipeffectparams.count(); k++) {
                     e = clipeffectparams.item(k).toElement();
                     if (!e.isNull() && e.tagName() == "parameter" && e.attribute("name") == paramname) {
+                        QString type = e.attribute("type");
                         QString factor = e.attribute("factor", "1");
                         double fact;
-                        if (factor.startsWith('%')) {
+                        if (factor.contains('%')) {
                             fact = ProfilesDialog::getStringEval(m_doc->mltProfile(), factor);
                         } else {
                             fact = factor.toDouble();
                         }
-                        if (e.attribute("type") == "simplekeyframe") {
+                        double offset = e.attribute("offset", "0").toDouble();
+                        if (type == "simplekeyframe") {
                             QStringList kfrs = paramvalue.split(";");
                             for (int l = 0; l < kfrs.count(); l++) {
                                 QString fr = kfrs.at(l).section('=', 0, 0);
-                                double val = kfrs.at(l).section('=', 1, 1).toDouble();
-                                kfrs[l] = fr + ":" + QString::number((int)(val * fact));
+                                double val = locale.toDouble(kfrs.at(l).section('=', 1, 1));
+                                //kfrs[l] = fr + ":" + locale.toString((int)(val * fact));
+                                kfrs[l] = fr + ":" + QString::number((int) (offset + val * fact));
                             }
                             e.setAttribute("keyframes", kfrs.join(";"));
-                        } else {
+                        } else if (type == "double" || type == "constant") {
                             bool ok;
-                            e.setAttribute("value", paramvalue.toDouble(&ok) * fact);
+                            e.setAttribute("value", offset + locale.toDouble(paramvalue, &ok) * fact);
                             if (!ok)
                                 e.setAttribute("value", paramvalue);
+                        } else {
+                            e.setAttribute("value", paramvalue);
                         }
                         break;
                     }
                 }
             }
-            if (effecttag == "ladspa") {
-                //QString ladspaEffectFile = EffectsList::parameter(effect, "src", "property");
-
-                if (!QFile::exists(ladspaEffectFile)) {
-                    // If the ladspa effect file is missing, recreate it
-                    initEffects::ladspaEffectFile(ladspaEffectFile, currenteffect.attribute("ladspaid").toInt(), m_trackview->getLadspaParams(currenteffect));
-                }
-                currenteffect.setAttribute("src", ladspaEffectFile);
-            }
+            
             if (disableeffect) currenteffect.setAttribute("disable", "1");
             if (clip)
                 clip->addEffect(currenteffect, false);
@@ -884,27 +951,50 @@ DocClipBase *TrackView::getMissingProducer(const QString id) const
     if (!docRoot.endsWith('/')) docRoot.append('/');
     QDomNodeList prods = doc.elementsByTagName("producer");
     int maxprod = prods.count();
+    bool slowmotionClip = false;
     for (int i = 0; i < maxprod; i++) {
         QDomNode m = prods.at(i);
         QString prodId = m.toElement().attribute("id");
+        if (prodId.startsWith("slowmotion")) {
+            slowmotionClip = true;
+            prodId = prodId.section(':', 1, 1);
+        }
+        prodId = prodId.section('_', 0, 0);
         if (prodId == id) {
             missingXml =  m.toElement();
             break;
         }
     }
-    if (missingXml == QDomElement()) return NULL;
-
-    QDomNodeList params = missingXml.childNodes();
-    QString resource;
-    for (int j = 0; j < params.count(); j++) {
-        QDomElement e = params.item(j).toElement();
-        if (e.attribute("name") == "resource") {
-            resource = e.firstChild().nodeValue();
-            break;
+    if (missingXml == QDomElement()) {
+        // Check if producer id was replaced in another track
+        if (m_replacementProducerIds.contains(id)) {
+            QString newId = m_replacementProducerIds.value(id);
+            slowmotionClip = false;
+            for (int i = 0; i < maxprod; i++) {
+                QDomNode m = prods.at(i);
+                QString prodId = m.toElement().attribute("id");
+                if (prodId.startsWith("slowmotion")) {
+                    slowmotionClip = true;
+                    prodId = prodId.section(':', 1, 1);
+                }
+                prodId = prodId.section('_', 0, 0);
+                if (prodId == id) {
+                    missingXml =  m.toElement();
+                    break;
+                }
+            }       
         }
     }
+    if (missingXml == QDomElement()) return NULL;
+    QString resource = EffectsList::property(missingXml, "resource");
+    QString service = EffectsList::property(missingXml, "mlt_service");
+
+    if (slowmotionClip) resource = resource.section('?', 0, 0);
     // prepend MLT XML document root if no path in clip resource and not a color clip
-    if (!resource.startsWith('/') && !resource.startsWith("0x")) resource.prepend(docRoot);
+    if (!resource.startsWith('/') && service != "colour") {
+        resource.prepend(docRoot);
+        kDebug()<<"******************\nADJUSTED 2\n*************************";
+    }
     DocClipBase *missingClip = NULL;
     if (!resource.isEmpty()) {
         QList <DocClipBase *> list = m_doc->clipManager()->getClipByResource(resource);
@@ -1010,4 +1100,37 @@ void TrackView::slotUpdateTrackEffectState(int ix)
     widgets.at(m_doc->tracksCount() - ix - 1)->updateEffectLabel(m_doc->trackInfoAt(ix).effectsList.effectNames());
 }
 
+void TrackView::slotSaveTimelinePreview(const QString path)
+{
+    QImage img(width(), height(), QImage::Format_ARGB32_Premultiplied);
+    img.fill(palette().base().color().rgb());
+    QPainter painter(&img);
+    render(&painter);
+    painter.end();
+    img = img.scaledToWidth(600, Qt::SmoothTransformation);
+    img.save(path);
+}
+
+void TrackView::updateProfile()
+{
+    m_ruler->updateFrameSize();
+    m_trackview->updateSceneFrameWidth();
+    slotChangeZoom(m_doc->zoom().x(), m_doc->zoom().y());
+    slotSetZone(m_doc->zone(), false);
+}
+
+void TrackView::checkTrackHeight()
+{
+    if (m_trackview->checkTrackHeight()) {
+        m_doc->clipManager()->clearCache();
+        m_ruler->updateFrameSize();
+        m_trackview->updateSceneFrameWidth();
+        slotChangeZoom(m_doc->zoom().x(), m_doc->zoom().y());
+        slotSetZone(m_doc->zone(), false);
+    }
+}
+
 #include "trackview.moc"
+
+
+
