@@ -108,10 +108,6 @@ private:
 
     /** @brief Returns the transition type for a given name. */
     TRANSITIONTYPE getTransitionForName(const QString & type);
-
-#if QT_VERSION >= 0x040600
-    QPropertyAnimation *m_startAnimation;
-#endif
 };
 
 #endif
